@@ -38,7 +38,7 @@
 #include <utime.h>
 #endif
 #ifndef Q_OS_WIN
-#include <unistd.h> // gethostname
+#include <unistd.h> // getuid
 #endif
 
 KCONFIGGROUP_DECLARE_ENUM_QOBJECT(KConfigTest, Testing)
@@ -102,6 +102,16 @@ static inline QString kdeGlobalsPath() {
     return QDir::cleanPath(testConfigDir() + "..") + "/kdeglobals";
 }
 
+#ifndef Q_OS_WIN
+void initLocale()
+{
+    setenv("LC_ALL", "en_US.utf-8", 1);
+    setenv("TZ", "UTC", 1);
+}
+
+Q_CONSTRUCTOR_FUNCTION(initLocale)
+#endif
+
 void KConfigTest::initTestCase()
 {
     // ensure we don't use files in the real config directory
@@ -338,7 +348,8 @@ void KConfigTest::testSimple()
     QCOMPARE(sc2.name(), QString(TEST_SUBDIR "kconfigtest"));
 
     // make sure groupList() isn't returning something it shouldn't
-    Q_FOREACH (const QString &group, sc2.groupList()) {
+    const QStringList lstGroup = sc2.groupList();
+    for (const QString &group : lstGroup) {
         QVERIFY(!group.isEmpty() && group != "<default>");
         QVERIFY(!group.contains(QChar(0x1d)));
     }
@@ -519,15 +530,15 @@ void KConfigTest::testPath()
         file.open(QIODevice::WriteOnly | QIODevice::Text);
         QTextStream out(&file);
         out.setCodec("UTF-8");
-        out << "[Test Group]" << endl
-            << "homePath=$HOME/foo" << endl
-            << "homePath2=file://$HOME/foo" << endl
-            << "withSlash=$WITHSLASH/foo" << endl
-            << "withSlash2=$WITHSLASH" << endl
-            << "withBraces[$e]=file://${HOME}/foo" << endl
-            << "URL[$e]=file://${HOME}/foo" << endl
-            << "hostname[$e]=$(hostname)" << endl
-            << "escapes=aaa,bb/b,ccc\\,ccc" << endl
+        out << "[Test Group]\n"
+            << "homePath=$HOME/foo\n"
+            << "homePath2=file://$HOME/foo\n"
+            << "withSlash=$WITHSLASH/foo\n"
+            << "withSlash2=$WITHSLASH\n"
+            << "withBraces[$e]=file://${HOME}/foo\n"
+            << "URL[$e]=file://${HOME}/foo\n"
+            << "hostname[$e]=$(hostname)\n"
+            << "escapes=aaa,bb/b,ccc\\,ccc\n"
             << "noeol=foo" // no EOL
             ;
     }
@@ -545,14 +556,8 @@ void KConfigTest::testPath()
     QCOMPARE(group.readPathEntry("withBraces", QString()), QString("file://" + HOMEPATH));
     QVERIFY(group.hasKey("URL"));
     QCOMPARE(group.readEntry("URL", QString()), QString("file://" + HOMEPATH));
-#if !defined(Q_OS_WIN32) && !defined(Q_OS_MAC)
-    // I don't know if this will work on windows
-    // This test hangs on OS X
     QVERIFY(group.hasKey("hostname"));
-    char hostname[256];
-    QVERIFY(::gethostname(hostname, sizeof(hostname)) == 0);
-    QCOMPARE(group.readEntry("hostname", QString()), QString::fromLatin1(hostname));
-#endif
+    QCOMPARE(group.readEntry("hostname", QString()), QStringLiteral("(hostname)")); // the $ got removed because empty var name
     QVERIFY(group.hasKey("noeol"));
     QCOMPARE(group.readEntry("noeol", QString()), QString("foo"));
 
@@ -587,10 +592,10 @@ void KConfigTest::testPathQtHome()
         file.open(QIODevice::WriteOnly | QIODevice::Text);
         QTextStream out(&file);
         out.setCodec("UTF-8");
-        out << "[Test Group]" << endl
-            << "dataDir[$e]=$QT_DATA_HOME/kconfigtest" << endl
-            << "cacheDir[$e]=$QT_CACHE_HOME/kconfigtest" << endl
-            << "configDir[$e]=$QT_CONFIG_HOME/kconfigtest" << endl;
+        out << "[Test Group]\n"
+            << "dataDir[$e]=$QT_DATA_HOME/kconfigtest\n"
+            << "cacheDir[$e]=$QT_CACHE_HOME/kconfigtest\n"
+            << "configDir[$e]=$QT_CONFIG_HOME/kconfigtest\n";
     }
     KConfig cf2(TEST_SUBDIR "pathtest");
     KConfigGroup group = cf2.group("Test Group");
@@ -753,7 +758,7 @@ void KConfigTest::testChangeGroup()
     KConfigGroup sc3(&sc, "Hello");
     QCOMPARE(sc3.name(), QString("Hello"));
     KConfigGroup newGroup(sc3);
-#ifndef KDE_NO_DEPRECATED
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 0)
     newGroup.changeGroup("FooBar"); // deprecated!
     QCOMPARE(newGroup.name(), QString("FooBar"));
     QCOMPARE(sc3.name(), QString("Hello")); // unchanged
@@ -769,7 +774,7 @@ void KConfigTest::testChangeGroup()
     KConfigGroup sc32(rootGroup.group("Hello"));
     QCOMPARE(sc32.name(), QString("Hello"));
     KConfigGroup newGroup2(sc32);
-#ifndef KDE_NO_DEPRECATED
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 0)
     newGroup2.changeGroup("FooBar"); // deprecated!
     QCOMPARE(newGroup2.name(), QString("FooBar"));
     QCOMPARE(sc32.name(), QString("Hello")); // unchanged
@@ -853,14 +858,16 @@ void KConfigTest::testDelete()
     QVERIFY(cf.sync());
 
     int count = 0;
-    Q_FOREACH (const QByteArray &item, readLines())
+    const QList<QByteArray> listLines = readLines();
+    for (const QByteArray &item : listLines)
         if (item.startsWith("devices|")) { // krazy:exclude=strings
             count++;
         }
     QCOMPARE(count, 2);
     cg.deleteEntry("devices|manual|/mnt/ipod");
     QVERIFY(cf.sync());
-    Q_FOREACH (const QByteArray &item, readLines()) {
+    const QList<QByteArray> listLines2 = readLines();
+    for (const QByteArray &item : listLines2) {
         QVERIFY(!item.contains("ipod"));
     }
 }
@@ -898,7 +905,8 @@ void KConfigTest::testDefaultGroup()
     QCOMPARE(lines.first(), QByteArray("TestKey=defaultGroup\n"));
 
     // Now that the group exists make sure it isn't returned from groupList()
-    Q_FOREACH (const QString &group, sc.groupList()) {
+    const QStringList groupList = sc.groupList();
+    for (const QString &group : groupList) {
         QVERIFY(!group.isEmpty() && group != "<default>");
     }
 
@@ -943,7 +951,8 @@ void KConfigTest::testEmptyGroup()
     QCOMPARE(lines.first(), QByteArray("TestKey=emptyGroup\n"));
 
     // Now that the group exists make sure it isn't returned from groupList()
-    Q_FOREACH (const QString &group, sc.groupList()) {
+    const QStringList groupList = sc.groupList();
+    for (const QString &group : groupList) {
         QVERIFY(!group.isEmpty() && group != "<default>");
     }
     emptyGroup.deleteGroup();
@@ -972,13 +981,13 @@ void KConfigTest::testCascadingWithLocale()
     QFile global(globalConfigDir + "foo.desktop");
     QVERIFY(global.open(QIODevice::WriteOnly | QIODevice::Text));
     QTextStream globalOut(&global);
-    globalOut << "[Group]" << endl
-              << "FromGlobal=true" << endl
-              << "FromGlobal[fr]=vrai" << endl
-              << "Name=Testing" << endl
-              << "Name[fr]=FR" << endl
-              << "Other=Global" << endl
-              << "Other[fr]=Global_FR" << endl;
+    globalOut << "[Group]\n"
+              << "FromGlobal=true\n"
+              << "FromGlobal[fr]=vrai\n"
+              << "Name=Testing\n"
+              << "Name[fr]=FR\n"
+              << "Other=Global\n"
+              << "Other[fr]=Global_FR\n";
     global.close();
 
     const QString middleConfigDir = middleDir.path() + "/" TEST_SUBDIR;
@@ -986,12 +995,12 @@ void KConfigTest::testCascadingWithLocale()
     QFile local(middleConfigDir + "foo.desktop");
     QVERIFY(local.open(QIODevice::WriteOnly | QIODevice::Text));
     QTextStream out(&local);
-    out << "[Group]" << endl
-        << "FromLocal=true" << endl
-        << "FromLocal[fr]=vrai" << endl
-        << "Name=Local Testing" << endl
-        << "Name[fr]=FR" << endl
-        << "Other=English Only" << endl;
+    out << "[Group]\n"
+        << "FromLocal=true\n"
+        << "FromLocal[fr]=vrai\n"
+        << "Name=Local Testing\n"
+        << "Name[fr]=FR\n"
+        << "Other=English Only\n";
     local.close();
 
     KConfig config(TEST_SUBDIR "foo.desktop");
@@ -1023,13 +1032,13 @@ void KConfigTest::testMerge()
         file.open(QIODevice::WriteOnly | QIODevice::Text);
         QTextStream out(&file);
         out.setCodec("UTF-8");
-        out << "[Merged Group]" << endl
-            << "entry1=Testing" << endl
-            << "entry2=More Testing" << endl
-            << "[some group]" << endl
-            << "entry[fr]=French" << endl
-            << "entry[es]=Spanish" << endl
-            << "entry[de]=German" << endl;
+        out << "[Merged Group]\n"
+            << "entry1=Testing\n"
+            << "entry2=More Testing\n"
+            << "[some group]\n"
+            << "entry[fr]=French\n"
+            << "entry[es]=Spanish\n"
+            << "entry[de]=German\n";
     }
     QVERIFY(config.sync());
 
@@ -1048,7 +1057,7 @@ void KConfigTest::testMerge()
               << "entry[fr]=French\n";
         QFile file(testConfigDir() + "/mergetest");
         file.open(QIODevice::ReadOnly | QIODevice::Text);
-        Q_FOREACH (const QByteArray &line, lines) {
+        for (const QByteArray &line : qAsConst(lines)) {
             QCOMPARE(line, file.readLine());
         }
     }
@@ -1061,10 +1070,10 @@ void KConfigTest::testImmutable()
         file.open(QIODevice::WriteOnly | QIODevice::Text);
         QTextStream out(&file);
         out.setCodec("UTF-8");
-        out << "[$i]" << endl
-            << "entry1=Testing" << endl
-            << "[group][$i]" << endl
-            << "[group][subgroup][$i]" << endl;
+        out << "[$i]\n"
+            << "entry1=Testing\n"
+            << "[group][$i]\n"
+            << "[group][subgroup][$i]\n";
     }
 
     KConfig config(TEST_SUBDIR "immutabletest", KConfig::SimpleConfig);
@@ -1086,9 +1095,9 @@ void KConfigTest::testOptionOrder()
         file.open(QIODevice::WriteOnly | QIODevice::Text);
         QTextStream out(&file);
         out.setCodec("UTF-8");
-        out << "[group3]" << endl
-            << "entry2=unlocalized" << endl
-            << "entry2[$i][de_DE]=t2" << endl;
+        out << "[group3]\n"
+            << "entry2=unlocalized\n"
+            << "entry2[$i][de_DE]=t2\n";
     }
     KConfig config(TEST_SUBDIR "doubleattrtest", KConfig::SimpleConfig);
     config.setLocale(QStringLiteral("de_DE"));
@@ -1111,7 +1120,7 @@ void KConfigTest::testOptionOrder()
 
         QFile file(testConfigDir() + "/doubleattrtest");
         file.open(QIODevice::ReadOnly | QIODevice::Text);
-        Q_FOREACH (const QByteArray &line, lines) {
+        for (const QByteArray &line : qAsConst(lines)) {
             QCOMPARE(line, file.readLine());
         }
     }
@@ -1190,7 +1199,8 @@ void KConfigTest::testSubGroup()
     QCOMPARE(groups, QStringList() << "NEG Child1" << "NEG Child4");
 
     // make sure groupList() isn't returning something it shouldn't
-    Q_FOREACH (const QString &group, sc.groupList()) {
+    const QStringList listGroup = sc.groupList();
+    for (const QString &group : listGroup) {
         QVERIFY(!group.isEmpty() && group != "<default>");
         QVERIFY(!group.contains(QChar(0x1d)));
         QVERIFY(!group.contains("subgroup"));
@@ -1341,7 +1351,7 @@ static void ageTimeStamp(const QString &path, int nsec)
 #ifdef Q_OS_UNIX
     QDateTime mtime = QFileInfo(path).lastModified().addSecs(-nsec);
     struct utimbuf utbuf;
-    utbuf.actime = mtime.toTime_t();
+    utbuf.actime = mtime.toSecsSinceEpoch();
     utbuf.modtime = utbuf.actime;
     utime(QFile::encodeName(path), &utbuf);
 #else
@@ -1736,10 +1746,11 @@ void KConfigTest::testQByteArrayUtf8()
     QFile readFile(file.fileName());
     QVERIFY(readFile.open(QFile::ReadOnly));
 #define VALUE "Utf8=\\x00\\x01\\x02\\x03\\x04\\x05\\x06\\x07\\x08\\t\\n\\x0b\\x0c\\r\\x0e\\x0f\\x10\\x11\\x12\\x13\\x14\\x15\\x16\\x17\\x18\\x19\\x1a\\x1b\\x1c\\x1d\\x1e\\x1f !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\\x7f\\x80\\x81\\x82\\x83\\x84\\x85\\x86\\x87\\x88\\x89\\x8a\\x8b\\x8c\\x8d\\x8e\\x8f\\x90\\x91\\x92\\x93\\x94\\x95\\x96\\x97\\x98\\x99\\x9a\\x9b\\x9c\\x9d\\x9e\\x9f\\xa0\\xa1\\xa2\\xa3\\xa4\\xa5\\xa6\\xa7\\xa8\\xa9\\xaa\\xab\\xac\\xad\\xae\\xaf\\xb0\\xb1\\xb2\\xb3\\xb4\\xb5\\xb6\\xb7\\xb8\\xb9\\xba\\xbb\\xbc\\xbd\\xbe\\xbf\\xc0\\xc1\\xc2\\xc3\\xc4\\xc5\\xc6\\xc7\\xc8\\xc9\\xca\\xcb\\xcc\\xcd\\xce\\xcf\\xd0\\xd1\\xd2\\xd3\\xd4\\xd5\\xd6\\xd7\\xd8\\xd9\\xda\\xdb\\xdc\\xdd\\xde\\xdf\\xe0\\xe1\\xe2\\xe3\\xe4\\xe5\\xe6\\xe7\\xe8\\xe9\\xea\\xeb\\xec\\xed\\xee\\xef\\xf0\\xf1\\xf2\\xf3\\xf4\\xf5\\xf6\\xf7\\xf8\\xf9\\xfa\\xfb\\xfc\\xfd\\xfe\\xff"
+    const QByteArray fileBytes = readFile.readAll();
 #ifndef Q_OS_WIN
-    QCOMPARE(readFile.readAll(), QByteArrayLiteral("[General]\n" VALUE "\n"));
+    QCOMPARE(fileBytes, QByteArrayLiteral("[General]\n" VALUE "\n"));
 #else
-    QCOMPARE(readFile.readAll(), QByteArrayLiteral("[General]\r\n" VALUE "\r\n"));
+    QCOMPARE(fileBytes, QByteArrayLiteral("[General]\r\n" VALUE "\r\n"));
 #endif
 #undef VALUE
 
@@ -1749,6 +1760,55 @@ void KConfigTest::testQByteArrayUtf8()
     QCOMPARE(bytes, general2.readEntry("Utf8", QByteArray()));
 }
 
+void KConfigTest::testQStringUtf8_data()
+{
+    QTest::addColumn<QByteArray>("data");
+    QTest::newRow("1") << QByteArray("Téléchargements\tTéléchargements");
+    QTest::newRow("2") << QByteArray("$¢ह€𐍈\t$¢ह€𐍈");
+    QTest::newRow("3") << QByteArray("\xc2\xe0\xa4\xf0\x90\x8d\t\\xc2\\xe0\\xa4\\xf0\\x90\\x8d");
+    // 2 byte overlong
+    QTest::newRow("4") << QByteArray("\xc1\xbf\t\\xc1\\xbf");
+    // 3 byte overlong
+    QTest::newRow("5") << QByteArray("\xe0\x9f\xbf\t\\xe0\\x9f\\xbf");
+    // 4 byte overlong
+    QTest::newRow("6") << QByteArray("\xf0\x8f\xbf\xbf\t\\xf0\\x8f\\xbf\\xbf");
+    // outside unicode range
+    QTest::newRow("7") << QByteArray("\xf4\x90\x80\x80\t\\xf4\\x90\\x80\\x80");
+    // just within range
+    QTest::newRow("8") << QByteArray("\xc2\x80\t\xc2\x80");
+    QTest::newRow("9") << QByteArray("\xe0\xa0\x80\t\xe0\xa0\x80");
+    QTest::newRow("10") << QByteArray("\xf0\x90\x80\x80\t\xf0\x90\x80\x80");
+    QTest::newRow("11") << QByteArray("\xf4\x8f\xbf\xbf\t\xf4\x8f\xbf\xbf");
+}
+
+void KConfigTest::testQStringUtf8()
+{
+    QFETCH(QByteArray, data);
+    const QList<QByteArray> d = data.split('\t');
+    const QByteArray value = d[0];
+    const QByteArray serialized = d[1];
+    QTemporaryFile file;
+    QVERIFY(file.open());
+    KConfig config(file.fileName(), KConfig::SimpleConfig);
+    KConfigGroup general(&config, "General");
+    general.writeEntry("key", value);
+    config.sync();
+    file.flush();
+    file.close();
+    QFile readFile(file.fileName());
+    QVERIFY(readFile.open(QFile::ReadOnly));
+    QByteArray fileBytes = readFile.readAll();
+#ifdef Q_OS_WIN
+    fileBytes.replace("\r\n", "\n");
+#endif
+    QCOMPARE(fileBytes, QByteArrayLiteral("[General]\nkey=") + serialized + QByteArrayLiteral("\n"));
+
+    // check that reading works
+    KConfig config2(file.fileName(), KConfig::SimpleConfig);
+    KConfigGroup general2(&config2, "General");
+    QCOMPARE(value, general2.readEntry("key", QByteArray()));
+}
+
 void KConfigTest::testNewlines()
 {
     // test that kconfig always uses the native line endings
@@ -1776,14 +1836,14 @@ void KConfigTest::testXdgListEntry()
     QTemporaryFile file;
     QVERIFY(file.open());
     QTextStream out(&file);
-    out <<  "[General]" << endl
-        << "Key1=" << endl // empty list
+    out <<  "[General]\n"
+        << "Key1=\n" // empty list
         // emtpty entries
-        << "Key2=;" << endl
-        << "Key3=;;" << endl
-        << "Key4=;;;" << endl
-        << "Key5=\\;" << endl
-        << "Key6=1;2\\;3;;" << endl;
+        << "Key2=;\n"
+        << "Key3=;;\n"
+        << "Key4=;;;\n"
+        << "Key5=\\;\n"
+        << "Key6=1;2\\;3;;\n";
     out.flush();
     file.close();
     KConfig anonConfig(file.fileName(), KConfig::SimpleConfig);
@@ -1816,7 +1876,7 @@ void KConfigTest::testThreads()
     // QEXPECT_FAIL triggers race conditions, it should be fixed to use QThreadStorage...
     //futures << QtConcurrent::run(this, &KConfigTest::testDeleteWhenLocalized);
     //futures << QtConcurrent::run(this, &KConfigTest::testEntryMap);
-    Q_FOREACH (QFuture<void> f, futures) { // krazy:exclude=foreach
+    for (QFuture<void> f : qAsConst(futures)) { // krazy:exclude=foreach
         f.waitForFinished();
     }
 }
@@ -1870,6 +1930,15 @@ void KConfigTest::testNotify()
     QCOMPARE(watcherSpy[0][0].value<KConfigGroup>().name(), QStringLiteral("TopLevelGroup"));
     QCOMPARE(watcherSpy[0][1].value<QByteArrayList>(), QByteArrayList({"entryA"}));
 
+    //revert to default an entry
+    watcherSpy.clear();
+    myConfigGroup.revertToDefault("entryA", KConfig::Persistent | KConfig::Notify);
+    config.sync();
+    watcherSpy.wait();
+    QCOMPARE(watcherSpy.count(), 1);
+    QCOMPARE(watcherSpy[0][0].value<KConfigGroup>().name(), QStringLiteral("TopLevelGroup"));
+    QCOMPARE(watcherSpy[0][1].value<QByteArrayList>(), QByteArrayList({"entryA"}));
+
     //deleting a group, should notify that every entry in that group has changed
     watcherSpy.clear();
     myConfigGroup.deleteGroup("aSubGroup", KConfig::Persistent | KConfig::Notify);
