@@ -24,23 +24,11 @@
 #include "kconfig_p.h"
 
 #include "config-kconfig.h"
+#include "kconfig_core_log_settings.h"
 
 #include <cstdlib>
 #include <fcntl.h>
 
-#ifdef _MSC_VER
-static inline FILE *popen(const char *cmd, const char *mode)
-{
-    return _popen(cmd, mode);
-}
-static inline int pclose(FILE *stream)
-{
-    return _pclose(stream);
-}
-#else
-#include <unistd.h>
-#endif
-
 #include "kconfigbackend_p.h"
 #include "kconfiggroup.h"
 
@@ -82,11 +70,17 @@ KConfigPrivate::KConfigPrivate(KConfig::OpenFlags flags,
       configState(KConfigBase::NoAccess)
 {
     static QBasicAtomicInt use_etc_kderc = Q_BASIC_ATOMIC_INITIALIZER(-1);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     if (use_etc_kderc.load() < 0) {
         use_etc_kderc.store( !qEnvironmentVariableIsSet("KDE_SKIP_KDERC"));    // for unit tests
     }
     if (use_etc_kderc.load()) {
-
+#else
+    if (use_etc_kderc.loadRelaxed() < 0) {
+        use_etc_kderc.storeRelaxed( !qEnvironmentVariableIsSet("KDE_SKIP_KDERC"));    // for unit tests
+    }
+    if (use_etc_kderc.loadRelaxed()) {
+#endif
         etc_kderc =
 #ifdef Q_OS_WIN
             QFile::decodeName(qgetenv("WINDIR") + "/kde5rc");
@@ -94,7 +88,11 @@ KConfigPrivate::KConfigPrivate(KConfig::OpenFlags flags,
             QStringLiteral("/etc/kde5rc");
 #endif
         if (!QFileInfo(etc_kderc).isReadable()) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             use_etc_kderc.store(false);
+#else
+            use_etc_kderc.storeRelaxed(false);
+#endif
             etc_kderc.clear();
         }
     }
@@ -183,29 +181,7 @@ QString KConfigPrivate::expandString(const QString &value)
     int nDollarPos = aValue.indexOf(QLatin1Char('$'));
     while (nDollarPos != -1 && nDollarPos + 1 < aValue.length()) {
         // there is at least one $
-        if (aValue[nDollarPos + 1] == QLatin1Char('(')) {
-            int nEndPos = nDollarPos + 1;
-            // the next character is not $
-            while ((nEndPos <= aValue.length()) && (aValue[nEndPos] != QLatin1Char(')'))) {
-                nEndPos++;
-            }
-            nEndPos++;
-            QString cmd = aValue.mid(nDollarPos + 2, nEndPos - nDollarPos - 3);
-
-            QString result;
-
-// FIXME: wince does not have pipes
-#ifndef _WIN32_WCE
-            FILE *fs = popen(QFile::encodeName(cmd).data(), "r");
-            if (fs) {
-                QTextStream ts(fs, QIODevice::ReadOnly);
-                result = ts.readAll().trimmed();
-                pclose(fs);
-            }
-#endif
-            aValue.replace(nDollarPos, nEndPos - nDollarPos, result);
-            nDollarPos += result.length();
-        } else if (aValue[nDollarPos + 1] != QLatin1Char('$')) {
+        if (aValue[nDollarPos + 1] != QLatin1Char('$')) {
             int nEndPos = nDollarPos + 1;
             // the next character is not $
             QStringRef aVarName;
@@ -236,11 +212,11 @@ QString KConfigPrivate::expandString(const QString &value)
                     if (!pEnv.isEmpty()) {
                         env = QString::fromLocal8Bit(pEnv.constData());
                     } else {
-                        if (aVarName == QStringLiteral("QT_DATA_HOME")) {
+                        if (aVarName == QLatin1String("QT_DATA_HOME")) {
                             env = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
-                        } else if (aVarName == QStringLiteral("QT_CONFIG_HOME")) {
+                        } else if (aVarName == QLatin1String("QT_CONFIG_HOME")) {
                             env = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation);
-                        } else if (aVarName == QStringLiteral("QT_CACHE_HOME")) {
+                        } else if (aVarName == QLatin1String("QT_CACHE_HOME")) {
                             env = QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation);
                         }
                     }
@@ -290,7 +266,11 @@ KConfig::KConfig(KConfigPrivate &d)
 KConfig::~KConfig()
 {
     Q_D(KConfig);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     if (d->bDirty && (d->mBackend && d->mBackend->ref.load() == 1)) {
+#else
+    if (d->bDirty && (d->mBackend && d->mBackend->ref.loadRelaxed() == 1)) {
+#endif
         sync();
     }
     delete d;
@@ -310,7 +290,7 @@ QStringList KConfig::groupList() const
         }
     }
 
-    return groups.toList();
+    return groups.values();
 }
 
 QStringList KConfigPrivate::groupList(const QByteArray &group) const
@@ -326,7 +306,7 @@ QStringList KConfigPrivate::groupList(const QByteArray &group) const
         }
     }
 
-    return groups.toList();
+    return groups.values();
 }
 
 static bool isGroupOrSubGroupMatch(const QByteArray &potentialGroup, const QByteArray &group)
@@ -379,7 +359,7 @@ QStringList KConfigPrivate::keyListImpl(const QByteArray &theGroup) const
                 tmp << QString::fromUtf8(key.mKey);
             }
         }
-        keys = tmp.toList();
+        keys = tmp.values();
     }
 
     return keys;
@@ -399,7 +379,7 @@ QMap<QString, QString> KConfig::entryMap(const QString &aGroup) const
     const QByteArray theGroup(aGroup.isEmpty() ? "<default>" : aGroup.toUtf8());
 
     const KEntryMapConstIterator theEnd = d->entryMap.constEnd();
-    KEntryMapConstIterator it = d->entryMap.findEntry(theGroup, nullptr, nullptr);
+    KEntryMapConstIterator it = d->entryMap.findEntry(theGroup, {}, {});
     if (it != theEnd) {
         ++it; // advance past the special group entry marker
 
@@ -443,7 +423,7 @@ bool KConfig::sync()
 
         // lock the local file
         if (d->configState == ReadWrite && !d->lockLocal()) {
-            qWarning() << "couldn't lock local file";
+            qCWarning(KCONFIG_CORE_LOG) << "couldn't lock local file";
             return false;
         }
 
@@ -473,7 +453,7 @@ bool KConfig::sync()
         if (d->wantGlobals() && writeGlobals) {
             QExplicitlySharedDataPointer<KConfigBackend> tmp = KConfigBackend::create(*sGlobalFileName);
             if (d->configState == ReadWrite && !tmp->lock()) {
-                qWarning() << "couldn't lock global file";
+                qCWarning(KCONFIG_CORE_LOG) << "couldn't lock global file";
 
                 //unlock the local config if we're returning early
                 if (d->mBackend->isLocked()) {
@@ -502,7 +482,7 @@ bool KConfig::sync()
     }
 
     if (!notifyGroupsLocal.isEmpty()) {
-        d->notifyClients(notifyGroupsLocal, QStringLiteral("/") + name());
+        d->notifyClients(notifyGroupsLocal, QLatin1Char('/') + name());
     }
     if (!notifyGroupsGlobal.isEmpty()) {
         d->notifyClients(notifyGroupsGlobal, QStringLiteral("/kdeglobals"));
@@ -554,7 +534,7 @@ void KConfig::checkUpdate(const QString &id, const QString &updateFile)
     const QString cfg_id = updateFile + QLatin1Char(':') + id;
     const QStringList ids = cg.readEntry("update_info", QStringList());
     if (!ids.contains(cfg_id)) {
-        QProcess::execute(QStringLiteral(KCONF_UPDATE_INSTALL_LOCATION), QStringList() << QStringLiteral("--check") << updateFile);
+        QProcess::execute(QStringLiteral(KCONF_UPDATE_INSTALL_LOCATION), QStringList { QStringLiteral("--check"), updateFile });
         reparseConfiguration();
     }
 }
@@ -878,10 +858,10 @@ bool KConfig::isImmutable() const
 bool KConfig::isGroupImmutableImpl(const QByteArray &aGroup) const
 {
     Q_D(const KConfig);
-    return isImmutable() || d->entryMap.getEntryOption(aGroup, nullptr, nullptr, KEntryMap::EntryImmutable);
+    return isImmutable() || d->entryMap.getEntryOption(aGroup, {},{}, KEntryMap::EntryImmutable);
 }
 
-#ifndef KDE_NO_DEPRECATED
+#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(4, 0)
 void KConfig::setForceGlobal(bool b)
 {
     Q_D(KConfig);
@@ -889,7 +869,7 @@ void KConfig::setForceGlobal(bool b)
 }
 #endif
 
-#ifndef KDE_NO_DEPRECATED
+#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(4, 0)
 bool KConfig::forceGlobal() const
 {
     Q_D(const KConfig);
@@ -909,7 +889,7 @@ const KConfigGroup KConfig::groupImpl(const QByteArray &group) const
 
 KEntryMap::EntryOptions convertToOptions(KConfig::WriteConfigFlags flags)
 {
-    KEntryMap::EntryOptions options = nullptr;
+    KEntryMap::EntryOptions options = {};
 
     if (flags & KConfig::Persistent) {
         options |= KEntryMap::EntryDirty;
