@@ -64,7 +64,7 @@ class KConfigPrivate;
  * KSharedConfig provides a set of open methods as counterparts for the
  * KConfig constructors.
  *
- * \sa KSharedConfig, KConfigGroup, <a href="http://techbase.kde.org/index.php?title=Development/Tutorials/KConfig">the techbase HOWTO on KConfig</a>.
+ * \sa KSharedConfig, KConfigGroup, <a href="https://techbase.kde.org/index.php?title=Development/Tutorials/KConfig">the techbase HOWTO on KConfig</a>.
  */
 class KCONFIGCORE_EXPORT KConfig : public KConfigBase
 {
@@ -77,7 +77,10 @@ public:
      * to provide defaults for the settings accessed through this object, or
      * possibly to override those settings in certain cases.
      *
-     * IncludeGlobals does the same, but with the global settings sources.
+     * If IncludeGlobals is selected, the kdeglobals configuration is used
+     * as additional configuration sources to provide defaults. Additionally
+     * selecting CascadeConfig will result in the system-wide kdeglobals sources
+     * also getting included.
      *
      * Note that the main configuration source overrides the cascaded sources,
      * which override those provided to addConfigSources(), which override the
@@ -321,29 +324,29 @@ public:
     /// @}
 
     /// @{ global
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(4, 0)
     /**
-     * @deprecated
-     *
      * Forces all following write-operations to be performed on @c kdeglobals,
      * independent of the @c Global flag in writeEntry().
      *
      * @param force true to force writing to kdeglobals
      * @see forceGlobal
+     * @deprecated Since 4.0
      */
-#ifndef KDE_NO_DEPRECATED
-    KCONFIGCORE_DEPRECATED void setForceGlobal(bool force);
+    KCONFIGCORE_DEPRECATED_VERSION(4, 0, "Not recommended")
+    void setForceGlobal(bool force);
 #endif
+
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(4, 0)
     /**
-     * @deprecated
-     *
      * Returns whether all entries are being written to @c kdeglobals.
      *
      * @return @c true if all entries are being written to @c kdeglobals
      * @see setForceGlobal
-     * @deprecated
+     * @deprecated Since 4.0
      */
-#ifndef KDE_NO_DEPRECATED
-    KCONFIGCORE_DEPRECATED bool forceGlobal() const;
+    KCONFIGCORE_DEPRECATED_VERSION(4, 0, "Not recommended")
+    bool forceGlobal() const;
 #endif
     /// @}
 
