@@ -20,6 +20,7 @@
 #include "kconfigwatcher.h"
 
 #include "config-kconfig.h"
+#include "kconfig_core_log_settings.h"
 
 #if KCONFIG_USE_DBUS
 #include <QDBusConnection>
@@ -68,9 +69,9 @@ KConfigWatcher::KConfigWatcher(const KSharedConfig::Ptr &config):
     d->m_config = config;
 
     QStringList watchedPaths;
-    watchedPaths <<QStringLiteral("/") + d->m_config->name();
-    for (const QString file: d->m_config->additionalConfigSources()) {
-        watchedPaths << QStringLiteral("/") + file;
+    watchedPaths << QLatin1Char('/') + d->m_config->name();
+    for (const QString &file: d->m_config->additionalConfigSources()) {
+        watchedPaths << QLatin1Char('/') + file;
     }
     if (d->m_config->openFlags() & KConfig::IncludeGlobals) {
         watchedPaths << QStringLiteral("/kdeglobals");
@@ -85,10 +86,17 @@ KConfigWatcher::KConfigWatcher(const KSharedConfig::Ptr &config):
                                               SLOT(onConfigChangeNotification(QHash<QString,QByteArrayList>)));
     }
 #else
-    qWarning() << "Use of KConfigWatcher without DBus support. You will not receive updates";
+    qCWarning(KCONFIG_CORE_LOG) << "Use of KConfigWatcher without DBus support. You will not receive updates";
 #endif
 }
 
+KConfigWatcher::~KConfigWatcher() = default;
+
+KSharedConfig::Ptr KConfigWatcher::config() const
+{
+    return d->m_config;
+}
+
 void KConfigWatcher::onConfigChangeNotification(const QHash<QString, QByteArrayList> &changes)
 {
     //should we ever need it we can determine the file changed with  QDbusContext::message().path(), but it doesn't seem too useful
