@@ -25,8 +25,8 @@
 #include <unistd.h>
 #endif
 
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
+#include <QDir>
+#include <QFileInfo>
 #include <QUrl>
 #include <qstandardpaths.h>
 
@@ -34,6 +34,7 @@
 #include "kconfig_p.h"
 #include "kconfiggroup.h"
 #include "kconfigini_p.h"
+#include "kconfig_core_log_settings.h"
 
 class KDesktopFilePrivate : public KConfigPrivate
 {
@@ -81,14 +82,16 @@ QString KDesktopFile::locateLocal(const QString &path)
     QString relativePath;
     QChar plus(QLatin1Char('/'));
     // Relative to config? (e.g. for autostart)
-    Q_FOREACH (const QString &dir, QStandardPaths::standardLocations(QStandardPaths::GenericConfigLocation)) {
+    const QStringList lstGenericConfigLocation = QStandardPaths::standardLocations(QStandardPaths::GenericConfigLocation);
+    for (const QString &dir : lstGenericConfigLocation) {
         if (path.startsWith(dir + plus)) {
             relativePath = path.mid(dir.length() + 1);
             return QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1Char('/') + relativePath;
         }
     }
     // Relative to xdg data dir? (much more common)
-    Q_FOREACH (const QString &dir, QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation)) {
+    const QStringList lstGenericDataLocation = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
+    for (const QString &dir : lstGenericDataLocation) {
         if (path.startsWith(dir + plus)) {
             relativePath = path.mid(dir.length() + 1);
         }
@@ -128,13 +131,14 @@ bool KDesktopFile::isAuthorizedDesktopFile(const QString &path)
 
     // Check if the .desktop file is installed as part of KDE or XDG.
     const QStringList appsDirs = QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
-    Q_FOREACH (const QString &prefix, appsDirs) {
+    for (const QString &prefix : appsDirs) {
         if (QDir(prefix).exists() && realPath.startsWith(QFileInfo(prefix).canonicalFilePath(), sensitivity)) {
             return true;
         }
     }
     const QString servicesDir = QStringLiteral("kservices5/"); // KGlobal::dirs()->xdgDataRelativePath("services")
-    Q_FOREACH (const QString &xdgDataPrefix, QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation)) {
+    const QStringList lstGenericDataLocation = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
+    for (const QString &xdgDataPrefix : lstGenericDataLocation) {
         if (QDir(xdgDataPrefix).exists()) {
             const QString prefix = QFileInfo(xdgDataPrefix).canonicalFilePath();
             if (realPath.startsWith(prefix + QLatin1Char('/') + servicesDir, sensitivity)) {
@@ -143,7 +147,8 @@ bool KDesktopFile::isAuthorizedDesktopFile(const QString &path)
         }
     }
     const QString autostartDir = QStringLiteral("autostart/");
-    Q_FOREACH (const QString &xdgDataPrefix, QStandardPaths::standardLocations(QStandardPaths::GenericConfigLocation)) {
+    const QStringList lstConfigPath = QStandardPaths::standardLocations(QStandardPaths::GenericConfigLocation);
+    for (const QString &xdgDataPrefix : lstConfigPath) {
         if (QDir(xdgDataPrefix).exists()) {
             const QString prefix = QFileInfo(xdgDataPrefix).canonicalFilePath();
             if (realPath.startsWith(prefix + QLatin1Char('/') + autostartDir, sensitivity)) {
@@ -154,7 +159,7 @@ bool KDesktopFile::isAuthorizedDesktopFile(const QString &path)
 
     // Forbid desktop files outside of standard locations if kiosk is set so
     if (!KAuthorized::authorize(QStringLiteral("run_desktop_files"))) {
-        qWarning() << "Access to '" << path << "' denied because of 'run_desktop_files' restriction." << endl;
+        qCWarning(KCONFIG_CORE_LOG) << "Access to '" << path << "' denied because of 'run_desktop_files' restriction.";
         return false;
     }
 
@@ -165,7 +170,7 @@ bool KDesktopFile::isAuthorizedDesktopFile(const QString &path)
         return true;
     }
 
-    qWarning() << "Access to '" << path << "' denied, not owned by root, executable flag not set." << endl;
+    qCWarning(KCONFIG_CORE_LOG) << "Access to '" << path << "' denied, not owned by root, executable flag not set.";
     return false;
 }
 
@@ -326,7 +331,7 @@ bool KDesktopFile::tryExec() const
 //QString
 //KDesktopFile::resource() const { return backEnd->resource(); }
 
-#ifndef KDE_NO_DEPRECATED
+#if KCONFIGCORE_BUILD_DEPRECATED_SINCE(5, 42)
 QStringList
 KDesktopFile::sortOrder() const
 {
@@ -370,12 +375,12 @@ bool KDesktopFile::noDisplay() const
         return true;
     }
     if (d->desktopGroup.hasKey("OnlyShowIn")) {
-        if (!d->desktopGroup.readXdgListEntry("OnlyShowIn").contains(QStringLiteral("KDE"))) {
+        if (!d->desktopGroup.readXdgListEntry("OnlyShowIn").contains(QLatin1String("KDE"))) {
             return true;
         }
     }
     if (d->desktopGroup.hasKey("NotShowIn")) {
-        if (d->desktopGroup.readXdgListEntry("NotShowIn").contains(QStringLiteral("KDE"))) {
+        if (d->desktopGroup.readXdgListEntry("NotShowIn").contains(QLatin1String("KDE"))) {
             return true;
         }
     }
