@@ -80,6 +80,8 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
 //Group Edit
     { Undo, "Undo", QT_TRANSLATE_NOOP3("KStandardShortcut", "Undo", "@action"), CTRL(Z), 0, QList<QKeySequence>(), false },
     { Redo, "Redo", QT_TRANSLATE_NOOP3("KStandardShortcut", "Redo", "@action"), CTRLSHIFT(Z), 0, QList<QKeySequence>(), false },
+    // Both "Cut" and "Delete" use Shift+Delete, but this is okay; see
+    // https://commits.kde.org/kxmlgui/8eabbf6725386e716b7536c71a9181dfe5d959f0
     { Cut, "Cut", QT_TRANSLATE_NOOP3("KStandardShortcut", "Cut", "@action"), CTRL(X), SHIFT(Delete), QList<QKeySequence>(), false },
     { Copy, "Copy", QT_TRANSLATE_NOOP3("KStandardShortcut", "Copy", "@action"), CTRL(C), CTRL(Insert), QList<QKeySequence>(), false },
     { Paste, "Paste", QT_TRANSLATE_NOOP3("KStandardShortcut", "Paste", "@action"), CTRL(V), SHIFT(Insert), QList<QKeySequence>(), false },
@@ -141,7 +143,7 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     { PrintPreview, "PrintPreview", QT_TRANSLATE_NOOP3("KStandardShortcut", "Print Preview", "@action"), 0, 0, QList<QKeySequence>(), false },
     { Mail, "Mail", QT_TRANSLATE_NOOP3("KStandardShortcut", "Mail", "@action"), 0, 0, QList<QKeySequence>(), false },
     { Clear, "Clear", QT_TRANSLATE_NOOP3("KStandardShortcut", "Clear", "@action"), 0, 0, QList<QKeySequence>(), false },
-    { ActualSize, "ActualSize", QT_TRANSLATE_NOOP3("KStandardShortcut", "Actual Size", "@action"), 0, 0, QList<QKeySequence>(), false },
+    { ActualSize, "ActualSize", QT_TRANSLATE_NOOP3("KStandardShortcut", "Actual Size", "@action"), CTRL(0), 0, QList<QKeySequence>(), false },
     { FitToPage, "FitToPage", QT_TRANSLATE_NOOP3("KStandardShortcut", "Fit To Page", "@action"), 0, 0, QList<QKeySequence>(), false },
     { FitToWidth, "FitToWidth", QT_TRANSLATE_NOOP3("KStandardShortcut", "Fit To Width", "@action"), 0, 0, QList<QKeySequence>(), false },
     { FitToHeight, "FitToHeight", QT_TRANSLATE_NOOP3("KStandardShortcut", "Fit To Height", "@action"), 0, 0, QList<QKeySequence>(), false },
@@ -154,9 +156,14 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     { Spelling, "Spelling", QT_TRANSLATE_NOOP3("KStandardShortcut", "Spelling", "@action"), 0, 0, QList<QKeySequence>(), false },
     { ShowToolbar, "ShowToolbar", QT_TRANSLATE_NOOP3("KStandardShortcut", "Show Toolbar", "@action"), 0, 0, QList<QKeySequence>(), false },
     { ShowStatusbar, "ShowStatusbar", QT_TRANSLATE_NOOP3("KStandardShortcut", "Show Statusbar", "@action"), 0, 0, QList<QKeySequence>(), false },
+#if KCONFIGGUI_BUILD_DEPRECATED_SINCE(5, 39)
     { SaveOptions, "SaveOptions", QT_TRANSLATE_NOOP3("KStandardShortcut", "Save Options", "@action"), 0, 0, QList<QKeySequence>(), false },
+#else
+    // dummy entry
+    { SaveOptions_DEPRECATED_DO_NOT_USE, nullptr, {nullptr, nullptr}, 0, 0, QList<QKeySequence>(), false },
+#endif
     { KeyBindings, "KeyBindings", QT_TRANSLATE_NOOP3("KStandardShortcut", "Key Bindings", "@action"), 0, 0, QList<QKeySequence>(), false },
-    { Preferences, "Preferences", QT_TRANSLATE_NOOP3("KStandardShortcut", "Preferences", "@action"), 0, 0, QList<QKeySequence>(), false },
+    { Preferences, "Preferences", QT_TRANSLATE_NOOP3("KStandardShortcut", "Configure Application", "@action"), CTRLSHIFT(Comma), 0, QList<QKeySequence>(), false },
     { ConfigureToolbars, "ConfigureToolbars", QT_TRANSLATE_NOOP3("KStandardShortcut", "Configure Toolbars", "@action"), 0, 0, QList<QKeySequence>(), false },
     { ConfigureNotifications, "ConfigureNotifications", QT_TRANSLATE_NOOP3("KStandardShortcut", "Configure Notifications", "@action"), 0, 0, QList<QKeySequence>(), false },
     { TipofDay, "TipofDay", QT_TRANSLATE_NOOP3("KStandardShortcut", "Tip Of Day", "@action"), 0, 0, QList<QKeySequence>(), false },
@@ -164,6 +171,8 @@ static KStandardShortcutInfo g_infoStandardShortcut[] = {
     { SwitchApplicationLanguage, "SwitchApplicationLanguage", QT_TRANSLATE_NOOP3("KStandardShortcut", "Switch Application Language", "@action"), 0, 0, QList<QKeySequence>(), false },
     { AboutApp, "AboutApp", QT_TRANSLATE_NOOP3("KStandardShortcut", "About Application", "@action"), 0, 0, QList<QKeySequence>(), false },
     { AboutKDE, "AboutKDE", QT_TRANSLATE_NOOP3("KStandardShortcut", "About KDE", "@action"), 0, 0, QList<QKeySequence>(), false },
+    // Both "Cut" and "Delete" use Shift+Delete, but this is okay; see
+    // https://commits.kde.org/kxmlgui/8eabbf6725386e716b7536c71a9181dfe5d959f0
     { DeleteFile, "DeleteFile", QT_TRANSLATE_NOOP3("KStandardShortcut", "Delete", "@action"), SHIFT(Delete), 0, QList<QKeySequence>(), false },
     { RenameFile, "RenameFile", QT_TRANSLATE_NOOP3("KStandardShortcut", "Rename", "@action"), Qt::Key_F2, 0, QList<QKeySequence>(), false },
     { MoveToTrash, "MoveToTrash", QT_TRANSLATE_NOOP3("KStandardShortcut", "Move to Trash", "@action"), Qt::Key_Delete, 0, QList<QKeySequence>(), false },
@@ -304,13 +313,13 @@ const QList<QKeySequence> &shortcut(StandardShortcut id)
 StandardShortcut find(const QKeySequence &seq)
 {
     if (!seq.isEmpty()) {
-        for (uint i = 0; i < sizeof(g_infoStandardShortcut) / sizeof(KStandardShortcutInfo); i++) {
-            StandardShortcut id = g_infoStandardShortcut[i].id;
+        for (const KStandardShortcutInfo &shortcutInfo : g_infoStandardShortcut) {
+            const StandardShortcut id = shortcutInfo.id;
             if (id != AccelNone) {
-                if (!g_infoStandardShortcut[i].isInitialized) {
+                if (!shortcutInfo.isInitialized) {
                     initialize(id);
                 }
-                if (g_infoStandardShortcut[i].cut.contains(seq)) {
+                if (shortcutInfo.cut.contains(seq)) {
                     return id;
                 }
             }
@@ -321,10 +330,11 @@ StandardShortcut find(const QKeySequence &seq)
 
 StandardShortcut find(const char *keyName)
 {
-    for (uint i = 0; i < sizeof(g_infoStandardShortcut) / sizeof(KStandardShortcutInfo); i++)
-        if (qstrcmp(g_infoStandardShortcut[i].name, keyName)) {
-            return g_infoStandardShortcut[i].id;
+    for (const KStandardShortcutInfo &shortcutInfo : g_infoStandardShortcut) {
+        if (qstrcmp(shortcutInfo.name, keyName)) {
+            return shortcutInfo.id;
         }
+    }
 
     return AccelNone;
 }
@@ -553,5 +563,9 @@ const QList<QKeySequence> &moveToTrash()
 {
     return shortcut(MoveToTrash);
 }
+const QList<QKeySequence> &preferences()
+{
+    return shortcut(Preferences);
+}
 
 }
